pub fn build_manifest(repo: &Repository) -> Result<Manifest>Expand description
Build a manifest from the current working tree (no commit written).
pub fn build_manifest(repo: &Repository) -> Result<Manifest>Build a manifest from the current working tree (no commit written).