WorkingTreeStatus

Struct WorkingTreeStatus 

pub struct WorkingTreeStatus {
    pub branch: Option<String>,
    pub new: Vec<PathBuf>,
    pub modified: Vec<PathBuf>,
    pub deleted: Vec<PathBuf>,
}
The difference between the working tree and a reference manifest (HEAD).

Fields

branch: Option<String>

Branch HEAD is on, if attached.

new: Vec<PathBuf>

Files present in the working tree but not in the manifest.

modified: Vec<PathBuf>

Files present in both but with different content.

deleted: Vec<PathBuf>

Files in the manifest but missing from the working tree.

Implementations

Source

impl WorkingTreeStatus

pub fn is_clean(&self) -> bool

Whether the working tree matches the manifest exactly.